@@ -1,9 +1,9 @@
 #
-# $Id: Factor.pm,v 0.05 2004/01/07 23:56:19 sts Exp $
+# $Id: Factor.pm,v 0.06 2004/01/08 07:13:59 sts Exp $
 
 package Math::Factor;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use integer;
 use strict 'vars';
@@ -140,20 +140,20 @@ sub each_factor {
     croak q~usage: each_factor (\%factors, $number)~
       unless ref $data_ref eq 'HASH' && $number;
 
-    unless (${__PACKAGE__.'::data'}) {
-        @{__PACKAGE__.'::data'} = @{$$data_ref{$number}};
-        ${__PACKAGE__.'::data'} = 1;
+    unless (${__PACKAGE__.'::each_factor'}) {
+        @{__PACKAGE__.'::each_factor'} = @{$$data_ref{$number}};
+        ${__PACKAGE__.'::each_factor'} = 1;
     }
 
-    if (@{__PACKAGE__.'::data'}) {
-        return shift @{__PACKAGE__.'::data'};
+    if (@{__PACKAGE__.'::each_factor'}) {
+        return shift @{__PACKAGE__.'::each_factor'};
     }
-    else { ${__PACKAGE__.'::data'} = 0; return }
+    else { ${__PACKAGE__.'::each_factor'} = 0; return }
 }
 
 =head2 each_match
 
-Returns each match of a number in array context.
+Returns each match of a number in a array context.
 
  while (@match = each_match(\%matches, $numbers[0])) {
      print "$numbers[0] == $match[0] * $match[1]\n";
@@ -166,17 +166,17 @@ sub each_match {
     croak q~usage: each_match (\%matches, $number)~
       unless ref $data_ref eq 'HASH' && $number;
 
-    unless (${__PACKAGE__.'::data'}) {
-        @{__PACKAGE__.'::data'} = @{$$data_ref{$number}};
-        ${__PACKAGE__.'::data'} = 1;
+    unless (${__PACKAGE__.'::each_match'}) {
+        @{__PACKAGE__.'::each_match'} = @{$$data_ref{$number}};
+        ${__PACKAGE__.'::each_match'} = 1;
     }
 
-    if (wantarray && @{__PACKAGE__.'::data'}) {
-        my @match = (${__PACKAGE__.'::data'}[0][0], ${__PACKAGE__.'::data'}[0][1]);
-        splice (@{__PACKAGE__.'::data'}, 0, 1);
+    if (wantarray && @{__PACKAGE__.'::each_match'}) {
+        my @match = (${__PACKAGE__.'::each_match'}[0][0], ${__PACKAGE__.'::each_match'}[0][1]);
+        splice (@{__PACKAGE__.'::each_match'}, 0, 1);
         return @match;
     }
-    else { ${__PACKAGE__.'::data'} = 0; return }
+    else { ${__PACKAGE__.'::each_match'} = 0; return }
 }
 
 =head2 show_factor
